@@ -24,11 +24,12 @@ const PopupMenu = imports.ui.popupMenu;
 const Slider = imports.ui.slider;
 const Main = imports.ui.main;
 
-const Gettext = imports.gettext.domain('EasyScreenCast@iacopodeenosee.gmail.com');
-const _ = Gettext.gettext;
-
 const ExtensionUtils = imports.misc.extensionUtils;
 const Me = ExtensionUtils.getCurrentExtension();
+
+const Domain = imports.gettext.domain(Me.metadata['gettext-domain']);
+const _ = Domain.gettext;
+
 const Lib = Me.imports.convenience;
 const Settings = Me.imports.settings;
 const Time = Me.imports.timer;
@@ -60,17 +61,34 @@ const EasyScreenCastIndicator = GObject.registerClass({
     _init() {
         super._init(null, 'EasyScreenCast_Indicator');
 
-        this.CtrlAudio = UtilAudio.getInstance();
+        this._settings = new Settings.Settings();
+        Lib.debugEnabled = this._settings.getOption('b', Settings.VERBOSE_DEBUG_SETTING_KEY);
+        this._settings._settings.connect(
+            `changed::${Settings.VERBOSE_DEBUG_SETTING_KEY}`,
+            () => {
+                Lib.debugEnabled = this._settings.getOption('b', Settings.VERBOSE_DEBUG_SETTING_KEY);
+            }
+        );
+
+        this.CtrlAudio = new UtilAudio.MixerAudio();
         this.CtrlWebcam = new UtilWebcam.HelperWebcam();
 
         this.CtrlNotify = new UtilNotify.NotifyManager();
         this.CtrlExe = new UtilExeCmd.ExecuteStuff(this);
 
+        // load indicator icons
+        this._icons = {
+            on: Lib.loadIcon('icon_recording.svg'),
+            onSel: Lib.loadIcon('icon_recordingSel.svg'),
+            off: Lib.loadIcon('icon_default.svg'),
+            offSel: Lib.loadIcon('icon_defaultSel.svg'),
+        };
+
         // check audio
         if (!this.CtrlAudio.checkAudio()) {
             Lib.TalkativeLog('-*-disable audio recording');
-            Settings.setOption(Settings.INPUT_AUDIO_SOURCE_SETTING_KEY, 0);
-            Settings.setOption(
+            this._settings.setOption(Settings.INPUT_AUDIO_SOURCE_SETTING_KEY, 0);
+            this._settings.setOption(
                 Settings.ACTIVE_CUSTOM_GSP_SETTING_KEY,
                 Settings.getGSPstd(false)
             );
@@ -84,7 +102,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
         );
 
         // prepare setting var
-        if (Settings.getOption('i', Settings.TIME_DELAY_SETTING_KEY) > 0) {
+        if (this._settings.getOption('i', Settings.TIME_DELAY_SETTING_KEY) > 0) {
             this.isDelayActive = true;
         } else {
             this.isDelayActive = false;
@@ -94,7 +112,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
         // Add the title bar icon and label for time display
         this.indicatorBox = new St.BoxLayout();
         this.indicatorIcon = new St.Icon({
-            gicon: Lib.ESCoffGIcon,
+            gicon: this._icons.off,
             icon_size: 16,
         });
         this.timeLabel = new St.Label({
@@ -201,7 +219,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
                 this.menu.close();
             }
 
-            this.isShowNotify = Settings.getOption('b', Settings.SHOW_NOTIFY_ALERT_SETTING_KEY);
+            this.isShowNotify = this._settings.getOption('b', Settings.SHOW_NOTIFY_ALERT_SETTING_KEY);
             this._doRecording();
         }
     }
@@ -242,7 +260,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
             this.smWebCam.menu.addMenuItem(arrMI[element]);
         }
 
-        let i = Settings.getOption('i', Settings.DEVICE_INDEX_WEBCAM_SETTING_KEY);
+        let i = this._settings.getOption('i', Settings.DEVICE_INDEX_WEBCAM_SETTING_KEY);
         Lib.TalkativeLog(`-*-populated submenuwebcam. Settings i=${i}`);
 
         this.smWebCam.label.text = this.WebCamDevice[i];
@@ -265,7 +283,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
         this.imRecordAction.x_fill = true;
         this.imRecordAction.x_align = Clutter.ActorAlign.CENTER;
         this.imRecordAction.connect('activate', () => {
-            this.isShowNotify = Settings.getOption('b', Settings.SHOW_NOTIFY_ALERT_SETTING_KEY);
+            this.isShowNotify = this._settings.getOption('b', Settings.SHOW_NOTIFY_ALERT_SETTING_KEY);
             this._doRecording();
         });
 
@@ -309,7 +327,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
             this.sub_menu_area_recording.menu.addMenuItem(arrMI[ele]);
         }
 
-        this.sub_menu_area_recording.label.text = this.AreaType[Settings.getOption('i', Settings.AREA_SCREEN_SETTING_KEY)];
+        this.sub_menu_area_recording.label.text = this.AreaType[this._settings.getOption('i', Settings.AREA_SCREEN_SETTING_KEY)];
         this.menu.addMenuItem(this.sub_menu_area_recording);
     }
 
@@ -325,7 +343,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
             this.smDelayRec.menu.addMenuItem(arrMI[ele]);
         }
 
-        var secDelay = Settings.getOption('i', Settings.TIME_DELAY_SETTING_KEY);
+        var secDelay = this._settings.getOption('i', Settings.TIME_DELAY_SETTING_KEY);
         if (secDelay > 0) {
             this.smDelayRec.label.text =
                 secDelay + _(' sec. delay before recording');
@@ -361,11 +379,11 @@ const EasyScreenCastIndicator = GObject.registerClass({
                 }
             );
 
-            (function (areaSetting, arr, item) {
+            (function (areaSetting, arr, item, settings) {
                 this.connectMI = function () {
                     this.connect('activate', () => {
                         Lib.TalkativeLog(`-*-set area recording to ${areaSetting} ${arr[areaSetting]}`);
-                        Settings.setOption(Settings.AREA_SCREEN_SETTING_KEY, areaSetting);
+                        settings.setOption(Settings.AREA_SCREEN_SETTING_KEY, areaSetting);
 
                         item.label.text = arr[areaSetting];
                     });
@@ -375,7 +393,8 @@ const EasyScreenCastIndicator = GObject.registerClass({
                 this.AreaMenuItem[i],
                 i,
                 this.AreaType,
-                this.sub_menu_area_recording
+                this.sub_menu_area_recording,
+                this._settings
             ));
         }
 
@@ -415,12 +434,12 @@ const EasyScreenCastIndicator = GObject.registerClass({
                 }
             );
 
-            (function (index, devPath, arr, item) {
+            (function (index, devPath, arr, item, settings) {
                 this.connectMI = function () {
                     this.connect('activate', () => {
                         Lib.TalkativeLog(`-*-set webcam device to ${index} ${arr[index]} devicePath=${devPath}`);
-                        Settings.setOption(Settings.DEVICE_INDEX_WEBCAM_SETTING_KEY, index);
-                        Settings.setOption(Settings.DEVICE_WEBCAM_SETTING_KEY, devPath);
+                        settings.setOption(Settings.DEVICE_INDEX_WEBCAM_SETTING_KEY, index);
+                        settings.setOption(Settings.DEVICE_WEBCAM_SETTING_KEY, devPath);
                         item.label.text = arr[index];
                     });
                 };
@@ -430,7 +449,8 @@ const EasyScreenCastIndicator = GObject.registerClass({
                 i,
                 devicePath,
                 this.WebCamDevice,
-                this.smWebCam
+                this.smWebCam,
+                this._settings
             ));
         }
 
@@ -494,17 +514,17 @@ const EasyScreenCastIndicator = GObject.registerClass({
             );
 
             // update choice audio from pref
-            if (i === Settings.getOption('i', Settings.INPUT_AUDIO_SOURCE_SETTING_KEY)) {
+            if (i === this._settings.getOption('i', Settings.INPUT_AUDIO_SOURCE_SETTING_KEY)) {
                 Lib.TalkativeLog(`-*-get audio choice from pref ${i}`);
                 this.sub_menu_audio_recording.label.text = this.AudioChoice[i].desc;
             }
 
             // add action on menu item
-            (function (audioIndex, arr, item) {
+            (function (audioIndex, arr, item, settings) {
                 this.connectMI = function () {
                     this.connect('activate', () => {
                         Lib.TalkativeLog(`-*-set audio choice to ${audioIndex}`);
-                        Settings.setOption(Settings.INPUT_AUDIO_SOURCE_SETTING_KEY, audioIndex);
+                        settings.setOption(Settings.INPUT_AUDIO_SOURCE_SETTING_KEY, audioIndex);
                         item.label.text = arr[audioIndex].desc;
                     });
                 };
@@ -513,7 +533,8 @@ const EasyScreenCastIndicator = GObject.registerClass({
                 this.AudioMenuItem[i],
                 i,
                 this.AudioChoice,
-                this.sub_menu_audio_recording
+                this.sub_menu_audio_recording,
+                this._settings
             ));
         }
         return this.AudioMenuItem;
@@ -531,7 +552,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
         this.DelayTimeLabel = new St.Label({
             text:
                 Math.floor(
-                    Settings.getOption('i', Settings.TIME_DELAY_SETTING_KEY)
+                    this._settings.getOption('i', Settings.TIME_DELAY_SETTING_KEY)
                 ).toString() + _(' Sec'),
         });
         this.DelayTimeTitle.actor.add_child(this.DelayTimeLabel);
@@ -540,7 +561,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
         this.imSliderDelay = new PopupMenu.PopupBaseMenuItem({
             activate: false,
         });
-        this.TimeSlider = new Slider.Slider(Settings.getOption('i', Settings.TIME_DELAY_SETTING_KEY) / 100);
+        this.TimeSlider = new Slider.Slider(this._settings.getOption('i', Settings.TIME_DELAY_SETTING_KEY) / 100);
         this.TimeSlider.x_expand = true;
         this.TimeSlider.y_expand = true;
 
@@ -567,10 +588,10 @@ const EasyScreenCastIndicator = GObject.registerClass({
         // enable key binding
         this._enableKeybindings();
         // immediately activate/deactive shortcut on settings change
-        Settings.settings.connect(
+        this._settings._settings.connect(
             `changed::${Settings.ACTIVE_SHORTCUT_SETTING_KEY}`,
             () => {
-                if (Settings.getOption('b', Settings.ACTIVE_SHORTCUT_SETTING_KEY)) {
+                if (this._settings.getOption('b', Settings.ACTIVE_SHORTCUT_SETTING_KEY)) {
                     Lib.TalkativeLog('-^-shortcut changed - enabling');
                     this._enableKeybindings();
                 } else {
@@ -623,10 +644,10 @@ const EasyScreenCastIndicator = GObject.registerClass({
      * @private
      */
     _doPreCommand() {
-        if (Settings.getOption('b', Settings.ACTIVE_PRE_CMD_SETTING_KEY)) {
+        if (this._settings.getOption('b', Settings.ACTIVE_PRE_CMD_SETTING_KEY)) {
             Lib.TalkativeLog('-*-execute pre command');
 
-            const PreCmd = Settings.getOption('s', Settings.PRE_CMD_SETTING_KEY);
+            const PreCmd = this._settings.getOption('s', Settings.PRE_CMD_SETTING_KEY);
 
             this.CtrlExe.Execute(
                 PreCmd,
@@ -640,7 +661,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
                         Lib.TalkativeLog('-*-pre command ERROR');
                         this.CtrlNotify.createNotify(
                             _('ERROR PRE COMMAND - See logs for more info'),
-                            Lib.ESCoffGIcon
+                            this._icons.off
                         );
                     }
                 },
@@ -664,7 +685,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
             pathFile = '';
 
             // get selected area
-            const optArea = Settings.getOption('i', Settings.AREA_SCREEN_SETTING_KEY);
+            const optArea = this._settings.getOption('i', Settings.AREA_SCREEN_SETTING_KEY);
             if (optArea > 0) {
                 Lib.TalkativeLog(`-*-type of selection of the area to record: ${optArea}`);
                 switch (optArea) {
@@ -705,11 +726,11 @@ const EasyScreenCastIndicator = GObject.registerClass({
      * @private
      */
     _doPostCommand() {
-        if (Settings.getOption('b', Settings.ACTIVE_POST_CMD_SETTING_KEY)) {
+        if (this._settings.getOption('b', Settings.ACTIVE_POST_CMD_SETTING_KEY)) {
             Lib.TalkativeLog('-*-execute post command');
 
             // launch cmd after registration
-            const tmpCmd = `/usr/bin/sh -c "${Settings.getOption('s', Settings.POST_CMD_SETTING_KEY)}"`;
+            const tmpCmd = `/usr/bin/sh -c "${this._settings.getOption('s', Settings.POST_CMD_SETTING_KEY)}"`;
 
             const mapObj = {
                 _fpath: pathFile,
@@ -741,7 +762,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
 
             Lib.TalkativeLog('-*-record OK');
             // update indicator
-            const indicators = Settings.getOption('i', Settings.STATUS_INDICATORS_SETTING_KEY);
+            const indicators = this._settings.getOption('i', Settings.STATUS_INDICATORS_SETTING_KEY);
             this._replaceStdIndicator(indicators === 1 || indicators === 3);
 
             if (this.isShowNotify) {
@@ -749,7 +770,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
                 // create counting notify
                 this.notifyCounting = this.CtrlNotify.createNotify(
                     _('Start Recording'),
-                    Lib.ESConGIcon
+                    this._icons.on
                 );
                 this.notifyCounting.connect('destroy', () => {
                     Lib.TalkativeLog('-*-notification destroyed');
@@ -775,7 +796,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
                 Lib.TalkativeLog('-*-show error notify');
                 this.CtrlNotify.createNotify(
                     _('ERROR RECORDER - See logs for more info'),
-                    Lib.ESCoffGIcon
+                    this._icons.off
                 );
             }
         }
@@ -792,14 +813,14 @@ const EasyScreenCastIndicator = GObject.registerClass({
                 this.CtrlNotify.updateNotify(
                     this.notifyCounting,
                     _(`EasyScreenCast -> Finish Recording / Seconds : ${sec}`),
-                    Lib.ESCoffGIcon,
+                    this._icons.off,
                     true
                 );
             } else {
                 this.CtrlNotify.updateNotify(
                     this.notifyCounting,
                     _('EasyScreenCast -> Recording in progress / Seconds passed : ') + sec,
-                    Lib.ESConGIcon,
+                    this._icons.on,
                     false
                 );
             }
@@ -819,7 +840,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
      */
     _onDelayTimeChanged() {
         const secDelay = Math.floor(this.TimeSlider.value * 100);
-        Settings.setOption(Settings.TIME_DELAY_SETTING_KEY, secDelay);
+        this._settings.setOption(Settings.TIME_DELAY_SETTING_KEY, secDelay);
         if (secDelay > 0) {
             this.smDelayRec.label.text = secDelay + _(' sec. delay before recording');
         } else {
@@ -833,29 +854,29 @@ const EasyScreenCastIndicator = GObject.registerClass({
     refreshIndicator(focus) {
         Lib.TalkativeLog(`-*-refresh indicator -A ${isActive} -F ${focus}`);
 
-        const indicators = Settings.getOption('i', Settings.STATUS_INDICATORS_SETTING_KEY);
+        const indicators = this._settings.getOption('i', Settings.STATUS_INDICATORS_SETTING_KEY);
 
         if (isActive === true) {
             if (indicators === 0 || indicators === 1) {
                 if (focus === true) {
-                    this.indicatorIcon.set_gicon(Lib.ESConGIconSel);
+                    this.indicatorIcon.set_gicon(this._icons.onSel);
                 } else {
-                    this.indicatorIcon.set_gicon(Lib.ESConGIcon);
+                    this.indicatorIcon.set_gicon(this._icons.on);
                 }
-            } else if (Settings.getOption('b', Settings.ACTIVE_SHORTCUT_SETTING_KEY)) {
+            } else if (this._settings.getOption('b', Settings.ACTIVE_SHORTCUT_SETTING_KEY)) {
                 this.indicatorIcon.set_gicon(null);
             } else if (focus === true) {
-                this.indicatorIcon.set_gicon(Lib.ESConGIconSel);
+                this.indicatorIcon.set_gicon(this._icons.onSel);
             } else {
-                this.indicatorIcon.set_gicon(Lib.ESConGIcon);
+                this.indicatorIcon.set_gicon(this._icons.on);
             }
 
             this.RecordingLabel.set_text(_('Stop recording'));
         } else {
             if (focus === true) {
-                this.indicatorIcon.set_gicon(Lib.ESCoffGIconSel);
+                this.indicatorIcon.set_gicon(this._icons.offSel);
             } else {
-                this.indicatorIcon.set_gicon(Lib.ESCoffGIcon);
+                this.indicatorIcon.set_gicon(this._icons.off);
             }
 
             this.RecordingLabel.set_text(_('Start recording'));
@@ -867,16 +888,41 @@ const EasyScreenCastIndicator = GObject.registerClass({
      * @private
      */
     _replaceStdIndicator(OPTtemp) {
-        if (Main.panel.statusArea['aggregateMenu']._screencast === undefined) {
+        if (Main.panel.statusArea === undefined) {
+            Lib.TalkativeLog('-*-no Main.panel.statusArea found');
+            return;
+        }
+
+        var stdMenu;
+
+        if (Main.panel.statusArea.quickSettings) {
+            // since gnome 43: aggregateMenu -> quickSettings
+            stdMenu = Main.panel.statusArea.quickSettings;
+        } else {
+            stdMenu = Main.panel.statusArea.aggregateMenu;
+        }
+
+        if (stdMenu === undefined) {
+            Lib.TalkativeLog('-*-no quickSettings or aggregateMenu in Main.panel.statusArea');
+            return;
+        }
+        if (stdMenu._remoteAccess === undefined) {
+            Lib.TalkativeLog('-*-no _remoteAccess indicator applet found');
+            return;
+        }
+        // since gnome 43: _recordingIndicator -> _indicator
+        var indicator = stdMenu._remoteAccess._indicator || stdMenu._remoteAccess._recordingIndicator;
+        if (indicator === undefined) {
+            Lib.TalkativeLog('-*-no _indicator or _recordingIndicator found');
             return;
         }
 
         if (OPTtemp) {
             Lib.TalkativeLog('-*-replace STD indicator');
-            Main.panel.statusArea['aggregateMenu']._screencast._indicator.visible = false;
+            indicator.visible = false;
         } else {
             Lib.TalkativeLog('-*-use STD indicator');
-            Main.panel.statusArea['aggregateMenu']._screencast._indicator.visible = isActive;
+            indicator.visible = isActive;
         }
     }
 
@@ -884,17 +930,18 @@ const EasyScreenCastIndicator = GObject.registerClass({
      * @private
      */
     _enableKeybindings() {
-        if (Settings.getOption('b', Settings.ACTIVE_SHORTCUT_SETTING_KEY)) {
+        if (this._settings.getOption('b', Settings.ACTIVE_SHORTCUT_SETTING_KEY)) {
             Lib.TalkativeLog('-*-enable keybinding');
 
             Main.wm.addKeybinding(
                 Settings.SHORTCUT_KEY_SETTING_KEY,
-                Settings.settings,
+                this._settings._settings,
                 Meta.KeyBindingFlags.NONE,
+                // available modes: https://gitlab.gnome.org/GNOME/gnome-shell/-/blob/main/src/shell-action-modes.h
                 Shell.ActionMode.NORMAL |
-                    Shell.ActionMode.MESSAGE_TRAY |
                     Shell.ActionMode.OVERVIEW |
-                    Shell.ActionMode.POPUP,
+                    Shell.ActionMode.POPUP |
+                    Shell.ActionMode.SYSTEM_MODAL,
                 () => {
                     Lib.TalkativeLog('-*-intercept key combination');
                     this._doRecording();
@@ -915,6 +962,29 @@ const EasyScreenCastIndicator = GObject.registerClass({
         }
     }
 
+    getSelectedRect() {
+        var recX = this._settings.getOption('i', Settings.X_POS_SETTING_KEY);
+        var recY = this._settings.getOption('i', Settings.Y_POS_SETTING_KEY);
+        var recW = this._settings.getOption('i', Settings.WIDTH_SETTING_KEY);
+        var recH = this._settings.getOption('i', Settings.HEIGHT_SETTING_KEY);
+        return [recX, recY, recW, recH];
+    }
+
+    saveSelectedRect(x, y, h, w) {
+        this._settings.setOption(Settings.X_POS_SETTING_KEY, x);
+        this._settings.setOption(Settings.Y_POS_SETTING_KEY, y);
+        this._settings.setOption(Settings.HEIGHT_SETTING_KEY, h);
+        this._settings.setOption(Settings.WIDTH_SETTING_KEY, w);
+    }
+
+    getSettings() {
+        return this._settings;
+    }
+
+    getAudioSource() {
+        return this.CtrlAudio.getAudioSource();
+    }
+
     /**
      * Destroy indicator
      */
@@ -925,6 +995,11 @@ const EasyScreenCastIndicator = GObject.registerClass({
             isActive = false;
         }
 
+        if (this._settings) {
+            this._settings.destroy();
+            this._settings = null;
+        }
+
         super.destroy();
     }
 });
@@ -933,12 +1008,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
  *
  */
 function init() {
-    Lib.TalkativeLog('-*-initExtension called');
-    Lib.TalkativeLog(`-*-version: ${Me.metadata.version}`);
-    Lib.TalkativeLog(`-*-install path: ${Me.path}`);
-    Lib.TalkativeLog(`-*-version (package.json): ${Lib.loadPackageJson().fullversion}`);
-
-    ExtensionUtils.initTranslations('EasyScreenCast@iacopodeenosee.gmail.com');
+    ExtensionUtils.initTranslations();
 }
 
 /**
@@ -946,6 +1016,9 @@ function init() {
  */
 function enable() {
     Lib.TalkativeLog('-*-enableExtension called');
+    Lib.TalkativeLog(`-*-version: ${Me.metadata.version}`);
+    Lib.TalkativeLog(`-*-install path: ${Me.path}`);
+    Lib.TalkativeLog(`-*-version (package.json): ${Lib.getFullVersion()}`);
 
     if (Indicator === null || Indicator === undefined) {
         Lib.TalkativeLog('-*-create indicator');
