@@ -32,17 +32,20 @@ const Layout = imports.ui.layout;
 
 const Main = imports.ui.main;
 
-const Gettext = imports.gettext.domain('EasyScreenCast@iacopodeenosee.gmail.com');
-const _ = Gettext.gettext;
-
 const ExtensionUtils = imports.misc.extensionUtils;
 const Me = ExtensionUtils.getCurrentExtension();
+
+const Domain = imports.gettext.domain(Me.metadata['gettext-domain']);
+const _ = Domain.gettext;
+
 const Lib = Me.imports.convenience;
-const Settings = Me.imports.settings;
 const Ext = Me.imports.extension;
 const UtilNotify = Me.imports.utilnotify;
 const DisplayApi = Me.imports.display_module.DisplayApi;
 
+const Config = imports.misc.config;
+const shellVersion = Number.parseInt(Config.PACKAGE_VERSION.split('.')[0]);
+
 /**
  * @type {Lang.Class}
  */
@@ -79,25 +82,28 @@ const Capture = GObject.registerClass({
 
         Main.uiGroup.add_actor(this._areaResolution);
 
-        if (Main.pushModal(this._areaSelection)) {
-            this._signalCapturedEvent = global.stage.connect(
-                'captured-event',
-                this._onCaptureEvent.bind(this)
-            );
+        this._grab = Main.pushModal(this._areaSelection);
+
+        if (this._grab) {
+            if (shellVersion >= 42) {
+                this._signalCapturedEvent = this._areaSelection.connect(
+                    'captured-event',
+                    this._onCaptureEvent.bind(this)
+                );
+            } else {
+                this._grab = this._areaSelection;
+                this._signalCapturedEvent = global.stage.connect(
+                    'captured-event',
+                    this._onCaptureEvent.bind(this)
+                );
+            }
+
+
 
             this._setCaptureCursor();
         } else {
             Lib.TalkativeLog('-£-Main.pushModal() === false');
         }
-
-        Main.sessionMode.connect('updated', () => this._updateDraw());
-    }
-
-    /**
-     * @private
-     */
-    _updateDraw() {
-        Lib.TalkativeLog('-£-update draw capture');
     }
 
     /**
@@ -179,7 +185,7 @@ const Capture = GObject.registerClass({
         global.stage.disconnect(this._signalCapturedEvent);
         this._setDefaultCursor();
         Main.uiGroup.remove_actor(this._areaSelection);
-        Main.popModal(this._areaSelection);
+        Main.popModal(this._grab);
         Main.uiGroup.remove_actor(this._areaResolution);
         this._areaSelection.destroy();
         this.emit('stop');
@@ -189,13 +195,13 @@ const Capture = GObject.registerClass({
     _saveRect(x, y, h, w) {
         Lib.TalkativeLog(`-£-selection x:${x} y:${y} height:${h} width:${w}`);
 
-        Settings.setOption(Settings.X_POS_SETTING_KEY, x);
-        Settings.setOption(Settings.Y_POS_SETTING_KEY, y);
-        Settings.setOption(Settings.HEIGHT_SETTING_KEY, h);
-        Settings.setOption(Settings.WIDTH_SETTING_KEY, w);
-
+        Ext.Indicator.saveSelectedRect(x, y, h, w);
         Ext.Indicator._doDelayAction();
     }
+
+    toString() {
+        return this.GTypeName;
+    }
 });
 
 Signals.addSignalMethods(Capture.prototype);
@@ -245,6 +251,10 @@ var SelectionArea = GObject.registerClass({
             }
         }
     }
+
+    toString() {
+        return this.GTypeName;
+    }
 });
 
 Signals.addSignalMethods(SelectionArea.prototype);
@@ -340,6 +350,10 @@ var SelectionWindow = GObject.registerClass({
         Lib.TalkativeLog('-£-window highlight off');
         this._capture.clearSelection();
     }
+
+    toString() {
+        return this.GTypeName;
+    }
 });
 
 Signals.addSignalMethods(SelectionWindow.prototype);
@@ -395,6 +409,10 @@ var SelectionDesktop = GObject.registerClass({
             this._capture._saveRect(x, y, height, width);
         }
     }
+
+    toString() {
+        return this.GTypeName;
+    }
 });
 
 Signals.addSignalMethods(SelectionDesktop.prototype);
@@ -417,11 +435,7 @@ var AreaRecording = GObject.registerClass({
             y: -10,
         });
 
-        var recX = Settings.getOption('i', Settings.X_POS_SETTING_KEY);
-        var recY = Settings.getOption('i', Settings.Y_POS_SETTING_KEY);
-        var recW = Settings.getOption('i', Settings.WIDTH_SETTING_KEY);
-        var recH = Settings.getOption('i', Settings.HEIGHT_SETTING_KEY);
-
+        var [recX, recY, recW, recH] = Ext.Indicator.getSelectedRect();
         var tmpH = Main.layoutManager.currentMonitor.height;
         var tmpW = Main.layoutManager.currentMonitor.width;
 
@@ -474,6 +488,10 @@ var AreaRecording = GObject.registerClass({
     isVisible() {
         return this._visible;
     }
+
+    toString() {
+        return this.GTypeName;
+    }
 });
 
 Signals.addSignalMethods(AreaRecording.prototype);
