@@ -18,15 +18,13 @@ const GLib = imports.gi.GLib;
 imports.gi.versions.Gst = '1.0';
 const Gst = imports.gi.Gst;
 
-const Gettext = imports.gettext.domain('EasyScreenCast@iacopodeenosee.gmail.com');
-const _ = Gettext.gettext;
-
 const ExtensionUtils = imports.misc.extensionUtils;
 const Me = ExtensionUtils.getCurrentExtension();
-const Lib = Me.imports.convenience;
 
-let ListDevices = null;
-let ListCaps = null;
+const Domain = imports.gettext.domain(Me.metadata['gettext-domain']);
+const _ = Domain.gettext;
+
+const Lib = Me.imports.convenience;
 
 var HelperWebcam = GObject.registerClass({
     GTypeName: 'EasyScreenCast_HelperWebcam',
@@ -129,15 +127,15 @@ var HelperWebcam = GObject.registerClass({
     refreshAllInputVideo() {
         Lib.TalkativeLog('-@-refresh all video input');
 
-        ListDevices = this.getDevicesIV();
+        this._listDevices = this.getDevicesIV();
         // compose devices array
-        ListCaps = [];
-        for (var index in ListDevices) {
-            ListCaps[index] = this.getCapsForIV(ListDevices[index].caps);
+        this._listCaps = [];
+        for (var index in this._listDevices) {
+            this._listCaps[index] = this.getCapsForIV(this._listDevices[index].caps);
 
-            Lib.TalkativeLog(`-@-webcam /dev/video${index} name: ${ListDevices[index].display_name}`);
-            Lib.TalkativeLog(`-@-caps available: ${ListCaps[index].length}`);
-            Lib.TalkativeLog(`-@-ListCaps[${index}]: ${ListCaps[index]}`);
+            Lib.TalkativeLog(`-@-webcam /dev/video${index} name: ${this._listDevices[index].display_name}`);
+            Lib.TalkativeLog(`-@-caps available: ${this._listCaps[index].length}`);
+            Lib.TalkativeLog(`-@-ListCaps[${index}]: ${this._listCaps[index]}`);
         }
     }
 
@@ -270,11 +268,11 @@ var HelperWebcam = GObject.registerClass({
         Lib.TalkativeLog('-@-get name devices');
         let tmpArray = [];
 
-        for (var index in ListDevices) {
+        for (var index in this._listDevices) {
             var wcName = _('Unspecified webcam');
 
-            if (ListDevices[index].display_name !== '') {
-                wcName = ListDevices[index].display_name;
+            if (this._listDevices[index].display_name !== '') {
+                wcName = this._listDevices[index].display_name;
             }
 
             tmpArray.push(wcName);
@@ -291,7 +289,7 @@ var HelperWebcam = GObject.registerClass({
      * @returns {string[]}
      */
     getListCapsDevice(index) {
-        const tmpArray = ListCaps[index];
+        const tmpArray = this._listCaps[index];
         Lib.TalkativeLog(`-@-list caps of device: ${tmpArray}`);
         return tmpArray;
     }
